diff --git a/include/mysql.php b/include/mysql.php
index 71ea2f073cbcd054853fb6a8f26eacd8d78bd3ea..06489242a71d78d7e8fae590ed8960ddfa74dee8 100644
--- a/include/mysql.php
+++ b/include/mysql.php
@@ -88,9 +88,9 @@
    	    }
                 
         if(!$result && $ost) { //error reporting
-            $alert='['.$query.']'."\n\n".db_error();
-            $ost->logError('DB Error #'.db_errno(), $alert, ($ost->alertONSQLError()));
-            //echo $alert; #uncomment during debuging or dev.
+            $msg='['.$query.']'."\n\n".db_error();
+            $ost->logDBError('DB Error #'.db_errno(), $msg);
+            //echo $msg; #uncomment during debuging or dev.
         }
 
         return $result;